@@ -10,7 +10,7 @@
 #define XBLAS_CONFIG_HPP
 
 #define XTENSOR_BLAS_VERSION_MAJOR 0
-#define XTENSOR_BLAS_VERSION_MINOR 2
+#define XTENSOR_BLAS_VERSION_MINOR 3
 #define XTENSOR_BLAS_VERSION_PATCH 0
 
 #ifndef USE_CXXLAPACK
@@ -21,6 +21,9 @@
 #define BLAS_IDX int
 #endif
 
+#pragma cling load("libblas")
+#pragma cling load("liblapack")
+
 namespace xt
 {
     using XBLAS_INDEX = int;
